@@ -1,14 +1,23 @@
 package ascii
 
 import (
+	"crypto/tls"
 	"image/gif"
 	"io"
 	"net/http"
 	"os"
+	"time"
 )
 
-func FromURL(url string) (*Renderer, error) {
-	resp, err := http.Get(url)
+func FromURL(url string, skipTLSVerify bool) (*Renderer, error) {
+	tr := &http.Transport{
+		TLSClientConfig: &tls.Config{InsecureSkipVerify: skipTLSVerify},
+	}
+	client := &http.Client{
+		Transport: tr,
+		Timeout:   time.Second * 30,
+	}
+	resp, err := client.Get(url)
 	if err != nil {
 		return nil, err
 	}
